==> plasma-framework-5.100.0.tar.xz: plasma-framework-5.100.0/src/desktoptheme/breeze-light/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze Light by the KDE VDG",
        "Description[az]": "Breeze -İşıqlı - KDE VDG tərəfindən",
        "Description[bg]": "Breeze Светъл от KDE VDG",
        "Description[ca@valencia]": "Brisa clara, creat pel VDG de KDE",
        "Description[ca]": "Brisa clara, creat pel VDG del KDE",
        "Description[cs]": "Breeze Light od KDE VDG",
        "Description[en_GB]": "Breeze Light by the KDE VDG",
        "Description[es]": "Brisa claro por KDE VDG",
        "Description[eu]": "Brisa argia, KDE VDGk egina",
        "Description[fi]": "Vaalea Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze clair par l'équipe « KDE VDG »",
        "Description[ia]": "Brisa Ligier per KDE VDG",
        "Description[id]": "Breeze Terang oleh KDE VDG",
        "Description[it]": "Brezza chiaro a cura del VDG di KDE",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 밝은 Breeze",
        "Description[nl]": "Breeze Light door de KDE VDG",
        "Description[nn]": "Breeze skumring frå KDE VDG",
        "Description[pl]": "Jasna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Claro da VDG do KDE",
        "Description[pt_BR]": "Breeze Light pelo KDE VDG",
        "Description[ru]": "Светлый вариант Breeze от KDE VDG",
        "Description[sl]": "Svetla sapica od KDE VDG",
        "Description[sv]": "Breeze ljus av KDE:s visuella designgrupp",
        "Description[tr]": "KDE VDG tarafından Esinti Açık",
        "Description[uk]": "Світла Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Sáng, do KDE VDG",
        "Description[x-test]": "xxBreeze Light by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风浅色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze Light",
        "Name[az]": "Breeze - İşıqlı",
        "Name[bg]": "Breeze Светъл",
        "Name[ca@valencia]": "Brisa clara",
        "Name[ca]": "Brisa clara",
        "Name[cs]": "Breeze Světlé",
        "Name[en_GB]": "Breeze Light",
        "Name[es]": "Brisa claro",
        "Name[eu]": "Brisa argia",
        "Name[fi]": "Vaalea Breeze",
        "Name[fr]": "Breeze clair",
        "Name[ia]": "Brisa Ligier",
        "Name[id]": "Breeze Terang",
        "Name[it]": "Brezza chiaro",
        "Name[ka]": "ნიავი ღია",
        "Name[ko]": "밝은 Breeze",
        "Name[nl]": "Breeze Light",
        "Name[nn]": "Breeze lys",
        "Name[pl]": "Jasna Bryza",
        "Name[pt]": "Brisa Clara",
        "Name[pt_BR]": "Breeze Light",
        "Name[ru]": "Breeze, светлый вариант",
        "Name[sl]": "Svetla sapica",
        "Name[sv]": "Breeze ljus",
        "Name[tr]": "Esinti Açık",
        "Name[uk]": "Світла Breeze",
        "Name[vi]": "Breeze Sáng",
        "Name[x-test]": "xxBreeze Lightxx",
        "Name[zh_CN]": "Breeze 微风浅色",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework_5.115.0.orig.tar.xz: plasma-framework-5.115.0/src/desktoptheme/breeze-light/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[de]": "KDE Visual Design Group",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ro]": "KDE Visual Design Group",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze Light by the KDE VDG",
        "Description[az]": "Breeze -İşıqlı - KDE VDG tərəfindən",
        "Description[be]": "Breeze Light ад KDE VDG",
        "Description[bg]": "Breeze Светъл от KDE VDG",
        "Description[ca@valencia]": "Brisa clara, creat pel VDG de KDE",
        "Description[ca]": "Brisa clara, creat pel VDG del KDE",
        "Description[cs]": "Breeze Light od KDE VDG",
        "Description[de]": "Breeze Hell von der KDE VDG",
        "Description[en_GB]": "Breeze Light by the KDE VDG",
        "Description[eo]": "Breeze Light de la KDE VDG",
        "Description[es]": "Brisa claro por KDE VDG",
        "Description[eu]": "Brisa argia, KDE VDGk egina",
        "Description[fi]": "Vaalea Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze clair par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa clara do KDE VDG.",
        "Description[ia]": "Brisa Ligier per KDE VDG",
        "Description[id]": "Breeze Terang oleh KDE VDG",
        "Description[it]": "Brezza chiaro a cura del VDG di KDE",
        "Description[ka]": "Breeze-ის ღია ვარიანტი, KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 밝은 Breeze",
        "Description[nl]": "Breeze Light door de KDE VDG",
        "Description[nn]": "Breeze skumring frå KDE VDG",
        "Description[pl]": "Jasna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Claro da VDG do KDE",
        "Description[pt_BR]": "Breeze Light pelo KDE VDG",
        "Description[ro]": "Briză, luminos, de KDE VDG",
        "Description[ru]": "Светлый вариант Breeze от KDE VDG",
        "Description[sl]": "Svetla sapica od KDE VDG",
        "Description[sv]": "Breeze ljus av KDE:s visuella designgrupp",
        "Description[tr]": "KDE VDG tarafından Esinti Açık",
        "Description[uk]": "Світла Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Sáng, do KDE VDG",
        "Description[x-test]": "xxBreeze Light by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风浅色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 設計的 Breeze Light",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze Light",
        "Name[az]": "Breeze - İşıqlı",
        "Name[be]": "Breeze Light",
        "Name[bg]": "Breeze Светъл",
        "Name[ca@valencia]": "Brisa clara",
        "Name[ca]": "Brisa clara",
        "Name[cs]": "Breeze Světlé",
        "Name[de]": "Breeze Hell",
        "Name[en_GB]": "Breeze Light",
        "Name[eo]": "Briza Lumo",
        "Name[es]": "Brisa claro",
        "Name[eu]": "Brisa argia",
        "Name[fi]": "Vaalea Breeze",
        "Name[fr]": "Breeze clair",
        "Name[gl]": "Brisa clara",
        "Name[ia]": "Brisa Ligier",
        "Name[id]": "Breeze Terang",
        "Name[it]": "Brezza chiaro",
        "Name[ka]": "ნიავი ღია",
        "Name[ko]": "밝은 Breeze",
        "Name[nl]": "Breeze Light",
        "Name[nn]": "Breeze lys",
        "Name[pl]": "Jasna Bryza",
        "Name[pt]": "Brisa Clara",
        "Name[pt_BR]": "Breeze Light",
        "Name[ro]": "Briză, luminos",
        "Name[ru]": "Breeze, светлый вариант",
        "Name[sl]": "Svetla sapica",
        "Name[sv]": "Breeze ljus",
        "Name[tr]": "Esinti Açık",
        "Name[uk]": "Світла Breeze",
        "Name[vi]": "Breeze Sáng",
        "Name[x-test]": "xxBreeze Lightxx",
        "Name[zh_CN]": "Breeze 微风浅色",
        "Name[zh_TW]": "Breeze Light",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
